# End to end research

In this tutorial, we show how to use Denario for end to end research, covering all the main Denario modules, from generating a research idea to write a full paper.

<div class="video-wrapper">
<iframe src="https://www.youtube.com/embed/xD58alMhHKg" frameborder="0"
                allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share"
                allowfullscreen></iframe>
</div>
